@@ -401,3 +401,84 @@ if ( !function_exists("get_fields") ) {
   }
 }
 
+
+if ( !function_exists("force_utf8") && isset($need_force_utf8) && $need_force_utf8 ) {
+  function define_byte_mappings() {
+    global $byte_map, $nibble_good_chars;
+
+    # Needed for using Grant McLean's byte mappings code
+    $ascii_char = '[\x00-\x7F]';
+    $cont_byte  = '[\x80-\xBF]';
+
+    $utf8_2     = '[\xC0-\xDF]' . $cont_byte;
+    $utf8_3     = '[\xE0-\xEF]' . $cont_byte . '{2}';
+    $utf8_4     = '[\xF0-\xF7]' . $cont_byte . '{3}';
+    $utf8_5     = '[\xF8-\xFB]' . $cont_byte . '{4}';
+
+    $nibble_good_chars = "/^($ascii_char+|$utf8_2|$utf8_3|$utf8_4|$utf8_5)(.*)$/s";
+
+    # From http://unicode.org/Public/MAPPINGS/VENDORS/MICSFT/WINDOWS/CP1252.TXT
+    $byte_map = array(
+        "\x80" => "\xE2\x82\xAC",  # EURO SIGN
+        "\x82" => "\xE2\x80\x9A",  # SINGLE LOW-9 QUOTATION MARK
+        "\x83" => "\xC6\x92",      # LATIN SMALL LETTER F WITH HOOK
+        "\x84" => "\xE2\x80\x9E",  # DOUBLE LOW-9 QUOTATION MARK
+        "\x85" => "\xE2\x80\xA6",  # HORIZONTAL ELLIPSIS
+        "\x86" => "\xE2\x80\xA0",  # DAGGER
+        "\x87" => "\xE2\x80\xA1",  # DOUBLE DAGGER
+        "\x88" => "\xCB\x86",      # MODIFIER LETTER CIRCUMFLEX ACCENT
+        "\x89" => "\xE2\x80\xB0",  # PER MILLE SIGN
+        "\x8A" => "\xC5\xA0",      # LATIN CAPITAL LETTER S WITH CARON
+        "\x8B" => "\xE2\x80\xB9",  # SINGLE LEFT-POINTING ANGLE QUOTATION MARK
+        "\x8C" => "\xC5\x92",      # LATIN CAPITAL LIGATURE OE
+        "\x8E" => "\xC5\xBD",      # LATIN CAPITAL LETTER Z WITH CARON
+        "\x91" => "\xE2\x80\x98",  # LEFT SINGLE QUOTATION MARK
+        "\x92" => "\xE2\x80\x99",  # RIGHT SINGLE QUOTATION MARK
+        "\x93" => "\xE2\x80\x9C",  # LEFT DOUBLE QUOTATION MARK
+        "\x94" => "\xE2\x80\x9D",  # RIGHT DOUBLE QUOTATION MARK
+        "\x95" => "\xE2\x80\xA2",  # BULLET
+        "\x96" => "\xE2\x80\x93",  # EN DASH
+        "\x97" => "\xE2\x80\x94",  # EM DASH
+        "\x98" => "\xCB\x9C",      # SMALL TILDE
+        "\x99" => "\xE2\x84\xA2",  # TRADE MARK SIGN
+        "\x9A" => "\xC5\xA1",      # LATIN SMALL LETTER S WITH CARON
+        "\x9B" => "\xE2\x80\xBA",  # SINGLE RIGHT-POINTING ANGLE QUOTATION MARK
+        "\x9C" => "\xC5\x93",      # LATIN SMALL LIGATURE OE
+        "\x9E" => "\xC5\xBE",      # LATIN SMALL LETTER Z WITH CARON
+        "\x9F" => "\xC5\xB8",      # LATIN CAPITAL LETTER Y WITH DIAERESIS
+    );
+
+    for( $i=160; $i < 256; $i++ ) {
+      $ch = chr($i);
+      $byte_map[$ch] = iconv('ISO-8859-1', 'UTF-8', $ch);
+    }
+  }
+  define_byte_mappings();
+
+  function force_utf8( $input ) {
+    $output = '';
+    $char   = '';
+    $rest   = '';
+    while( $input != '' ) {
+      if ( preg_match( $nibble_good_chars, $input, $matches ) ) {
+        $output .= $matches[1];
+        $rest = $matches[2];
+      }
+      else {
+        preg_match( '/^(.)(.*)$/s', $input, $matches );
+        $char = $matches[1];
+        $rest = $matches[2];
+        if ( isset($byte_map[$char]) ) {
+          $output .= $byte_map[$char];
+        }
+        else {
+          # Must be valid UTF8 already
+          $output .= $char;
+        }
+      }
+      $input = $rest;
+    }
+    return $output;
+  }
+
+}
