@@ -66,7 +66,9 @@ function connect_configured_database() {
   $dbconn = false;
   if ( isset($c->pg_connect) && is_array($c->pg_connect) ) {
     foreach( $c->pg_connect AS $k => $v ) {
-      if ( !$dbconn ) $dbconn = ((isset($c->use_persistent) && $c->use_persistent) ? pg_pConnect($v) : pg_Connect($v) );
+      if ( !$dbconn ) {
+        if ( $dbconn = ((isset($c->use_persistent) && $c->use_persistent) ? pg_pConnect($v) : pg_Connect($v) ) ) break;
+      }
     }
   }
   if ( ! $dbconn ) {
@@ -83,6 +85,11 @@ EOERRMSG;
     exit;
   }
 
+  if ( isset($c->db_schema) && $c->db_schema != '' ) {
+    $result = pg_exec( $dbconn, "SET Search_path TO ".$c->db_schema.",public;" );
+    $row = pg_fetch_array($result, 0);
+  }
+
   $result = pg_exec( $dbconn, "SELECT version()" );
   $row = pg_fetch_array($result, 0);
   $c->found_dbversion = preg_replace( '/^PostgreSQL (\d+\.\d+)\..*$/i', '$1', $row[0]);
@@ -167,6 +174,14 @@ function qpg($str = null) {
 * @return string The pristine uncontaminated string we can safely use for Just About Anything(tm).
 */
 function clean_string( $unclean, $type = 'full' ) {
+  if ( ! isset($unclean) ) return null;
+  if ( is_array($unclean) ) {
+    $result = array();
+    foreach( $unclean AS $k => $v ) {
+      $result[$k] = clean_string( $v, $type );
+    }
+    return $result;
+  }
   if ( $type != 'basic' ) $cleaned = strtolower($unclean); else $cleaned = &$unclean;
   $cleaned = preg_replace( "/['\"!\\\\()\[\]|*\/{}&%@~;:?<>]/", '', $cleaned ); //"// Stupid Bluefish Syntax highlighting...
   dbg_error_log( "PgQuery", "clean_string: Cleaned string from <<%s>> to <<%s>>", $unclean, $cleaned );
