@@ -367,7 +367,7 @@ class Session
             $this->Session($sid);
             dbg_error_log( "Login", " Login: New session $session_id started for $username ($usr->user_no)" );
             if ( isset($_POST['remember']) && intval($_POST['remember']) > 0 ) {
-              $cookie .= md5( $usr->user_no ) . ";";
+              $cookie = md5( $usr->user_no ) . ";";
               $cookie .= session_salted_md5($usr->user_no . $usr->username . $usr->password);
               $GLOBALS['lsid'] = $cookie;
               setcookie( "lsid", $cookie, time() + (86400 * 3600), "/" );   // will expire in ten or so years
@@ -587,14 +587,15 @@ EOTEXT;
     if ( $this->logged_in && $groups == "" ) return;
     if ( ! $this->logged_in ) {
       $c->messages[] = i18n("You must log in to use this system.");
-      include_once("page-header.php");
       if ( function_exists("local_index_not_logged_in") ) {
         local_index_not_logged_in();
       }
       else {
+        include("page-header.php");
         $login_html = translate( "<h1>Log On Please</h1><p>For access to the %s you should log on withthe username and password that have been issued to you.</p><p>If you would like to request access, please e-mail %s.</p>");
         printf( $login_html, $c->system_name, $c->admin_email );
         echo $this->RenderLoginPanel();
+        include("page-footer.php");
       }
     }
     else {
@@ -603,10 +604,10 @@ EOTEXT;
         if ( $this->AllowedTo($v) ) return;
       }
       $c->messages[] = i18n("You are not authorised to use this function.");
-      include_once("page-header.php");
+      include("page-header.php");
+      include("page-footer.php");
     }
 
-    include("page-footer.php");
     exit;
   }
 
@@ -649,7 +650,7 @@ EOTEXT;
         $usernames = "";
         if ( isset($c->debug_email) ) {
           $debug_to = "This e-mail would normally be sent to:\n ";
-          $mail->AddTo( "WRMS Tester <$c->debug_email>" );
+          $mail->AddTo( "Tester <$c->debug_email>" );
         }
         while ( $row = $qry->Fetch() ) {
           $sql .= "INSERT INTO tmp_password ( user_no, password) VALUES( $row->user_no, '$tmp_passwd');";
@@ -706,9 +707,9 @@ EOTEXT;
 *
 */
   function SendTemporaryPassword( ) {
-    global $c;
+    global $c, $page_elements;
 
-    $password_sent = $this->EmailTemporaryPassword( $_POST['username'], $_POST['email_address'] );
+    $password_sent = $this->EmailTemporaryPassword( (isset($_POST['username'])?$_POST['username']:null), (isset($_POST['email_address'])?$_POST['email_address']:null) );
 
     if ( ! $password_sent && ((isset($_POST['username']) && $_POST['username'] != "" )
                               || (isset($_POST['email_address']) && $_POST['email_address'] != "" )) ) {
@@ -765,9 +766,14 @@ on will have the existing password invalidated.</p>
 </div>
 EOTEXT;
     }
-    include_once("page-header.php");
+    if ( isset($page_elements) && gettype($page_elements) == 'array' ) {
+      $page_elements[] = $page_content;
+      @include("page-renderer.php");
+      exit(0);
+    }
+    @include("page-header.php");
     echo $page_content;
-    include_once("page-footer.php");
+    @include("page-footer.php");
     exit(0);
   }
 
